summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/networkstatuscommon.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/networkstatuscommon.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/networkstatuscommon.h')
-rw-r--r--kopete/libkopete/networkstatuscommon.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/libkopete/networkstatuscommon.h b/kopete/libkopete/networkstatuscommon.h
index a243be43..81ac8350 100644
--- a/kopete/libkopete/networkstatuscommon.h
+++ b/kopete/libkopete/networkstatuscommon.h
@@ -3,31 +3,31 @@
#include <tqstringlist.h>
-namespace NetworkStatus
+namespace NetworktqStatus
{
- enum EnumStatus { NoNetworks = 1, Unreachable, OfflineDisconnected, OfflineFailed, ShuttingDown, Offline, Establishing, Online };
+ enum EnumtqStatus { NoNetworks = 1, Unreachable, OfflineDisconnected, OfflineFailed, ShuttingDown, Offline, Establishing, Online };
enum EnumRequestResult { RequestAccepted = 1, Connected, UserRefused, Unavailable };
enum EnumOnDemandPolicy { All, User, None, Permanent };
struct Properties
{
TQString name;
// status of the network
- EnumStatus status;
+ EnumtqStatus status;
// policy for on-demand usage as defined by the service
EnumOnDemandPolicy onDemandPolicy;
// identifier for the service
TQCString service;
// indicate that the connection is to 'the internet' - similar to default gateway in routing
bool internet;
- // list of netmasks that the network connects to - overridden by above internet
- TQStringList netmasks;
+ // list of nettqmasks that the network connects to - overridden by above internet
+ TQStringList nettqmasks;
// for future expansion consider
// EnumChargingModel - FlatRate, TimeCharge, VolumeCharged
- // EnumLinkStatus - for WLANs - VPOOR, POOR, AVERAGE, GOOD, EXCELLENT
+ // EnumLinktqStatus - for WLANs - VPOOR, POOR, AVERAGE, GOOD, EXCELLENT
};
}
-TQDataStream & operator>> ( TQDataStream & s, NetworkStatus::Properties &p );
-TQDataStream & operator<< ( TQDataStream & s, const NetworkStatus::Properties p );
+TQDataStream & operator>> ( TQDataStream & s, NetworktqStatus::Properties &p );
+TQDataStream & operator<< ( TQDataStream & s, const NetworktqStatus::Properties p );
#endif